@@ -15,6 +15,9 @@ This package contains modules for performing various analysis tasks:
 :mod:`~sapphire.analysis.direction_reconstruction`
     EAS direction reconstruction
 
+:mod:`~sapphire.analysis.find_mpv`
+    Module for finding the MIP peak MPV in pulseintegral data
+
 :mod:`~sapphire.analysis.landau`
     Landau distribution
 
@@ -22,5 +25,19 @@ This package contains modules for performing various analysis tasks:
     Process HiSPARC events
 
 """
-from direction_reconstruction import (DirectionReconstruction,
-                                      BinnedDirectionReconstruction)
+from . import coincidence_queries
+from . import coincidences
+from . import core_reconstruction
+from . import direction_reconstruction
+from . import find_mpv
+from . import landau
+from . import process_events
+
+
+__all__ = ['coincidence_queries',
+           'coincidences',
+           'core_reconstruction',
+           'direction_reconstruction',
+           'find_mpv',
+           'landau',
+           'process_events']
