@@ -404,7 +404,7 @@ class Coincidences(object):
             event_idx) which will be searched
         :param window: the time window in nanoseconds which will be searched
             for coincidences.  Events falling outside this window will not be
-            part of the coincidence.  Default: 200000 (i.e. 200 us).
+            part of the coincidence.
 
         :return: a list of coincidences, which each consist of a list with
             indexes into the timestamps array as a pointer to the events
@@ -500,6 +500,7 @@ class CoincidencesESD(Coincidences):
             s_columns = {'s%d' % station.number: tables.BoolCol(pos=p)
                          for p, station in enumerate(cluster.stations, 12)}
         else:
+            self.cluster = None
             s_columns = {'s%d' % n: tables.BoolCol(pos=(n + 12))
                          for n, _ in enumerate(self.station_groups)}
 
